@@ -3,7 +3,7 @@
  * TAC.C - Nagios Tactical Monitoring Overview CGI
  *
  * Copyright (c) 2001-2006 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 08-22-2006
+ * Last Modified: 03-21-2006
  *
  * This CGI program will display the contents of the Nagios
  * log file.
@@ -285,13 +285,8 @@ int main(void){
 		sound=service_warning_sound;
 	else if(services_unknown_unacknowledged==0 && services_warning_unacknowledged==0 && services_critical_unacknowledged==0 && hosts_down_unacknowledged==0 && hosts_unreachable_unacknowledged==0 && normal_sound!=NULL)
 		sound=normal_sound;
-	if(sound!=NULL){
-		printf("<object type=\"application/x-mplayer2\" height=\"-\" width=\"0\">");
-		printf("<param name=\"filename\" value=\"%s%s\">",url_media_path,sound);
-		printf("<param name=\"autostart\" value=\"1\">");
-		printf("<param name=\"playcount\" value=\"1\">");
-		printf("</object>");
-		}
+	if(sound!=NULL)
+		printf("<EMBED SRC='%s%s' HIDDEN=TRUE AUTOSTART=TRUE>",url_media_path,sound);
 
 
 	/**** display main tac screen ****/
